Subselection of valid SWC and H5 files for testing file loading.
----------------------------------------------------------------

Note:

* This directory contains soft links only.
* Adding or removing files may cause IO unit tests to fail.
